@@ -1,24 +1,8 @@
 /*
- * This file is part of kdev-python
- * Copyright 2013  Sven Brauch <svenbrauch@gmail.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    SPDX-FileCopyrightText: 2013 Sven Brauch <svenbrauch@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "docfilewizard.h"
 #include "docfilemanagerwidget.h"
@@ -46,7 +30,7 @@
 
 DocfileWizard::DocfileWizard(const QString& workingDirectory, QWidget* parent)
     : QDialog(parent)
-    , worker(0)
+    , worker(nullptr)
     , workingDirectory(workingDirectory)
 {
     setLayout(new QVBoxLayout);
@@ -177,7 +161,7 @@ bool DocfileWizard::run()
     worker = new QProcess(this);
     QObject::connect(worker, &QProcess::readyReadStandardError, this, &DocfileWizard::processScriptOutput);
     QObject::connect(worker, &QProcess::readyReadStandardOutput, this, &DocfileWizard::processScriptOutput);
-    QObject::connect(worker, SIGNAL(finished(int)), this, SLOT(processFinished(int)));
+    QObject::connect(worker, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &DocfileWizard::processFinished);
 
     // can never have too many slashes
     outputFile.setFileName(workingDirectory + "/" + outputFilename);
@@ -238,9 +222,9 @@ void DocfileWizard::processScriptOutput()
     scrollbar->setValue(scrollbar->maximum());
 }
 
-void DocfileWizard::processFinished(int)
+void DocfileWizard::processFinished(int, QProcess::ExitStatus)
 {
-    worker = 0;
+    worker = nullptr;
     runButton->setEnabled(true);
     saveButton->setEnabled(true);
 }
@@ -255,3 +239,5 @@ void DocfileWizard::updateOutputFilename(const QString& newModuleName)
     }
     previousModuleName = newModuleName;
 }
+
+#include "moc_docfilewizard.cpp"
